@@ -1,4 +1,4 @@
-# $Id: Echostar.pm,v 1.3 2003-07-27 21:15:36-04 kingpin Exp kingpin $
+# $Id: Echostar.pm,v 1.6 2003-08-28 07:13:02-04 kingpin Exp kingpin $
 
 =head1 NAME
 
@@ -18,31 +18,10 @@ WWW::Search::Yahoo::TV::Echostar - backend for searching tv.yahoo.com
 This class is a Yahoo specialization of L<WWW::Search>.  It handles
 making and interpreting Yahoo TV searches F<http://tv.yahoo.com>.
 
-This class exports no public interface; all interaction should
-be done through L<WWW::Search> objects.
+=head1 METHODS
 
-=head1 NOTES
-
-This backend does a basic keyword search against the Echostar (Dish
-Network) East Coast channel lineup.
-
-=head1 SEE ALSO
-
-To make new back-ends, see L<WWW::Search>.
-
-=head1 BUGS
-
-Please tell the author if you find any!
-
-=head1 AUTHOR
-
-Martin Thurn C<mthurn@cpan.org>
-
-=head1 LEGALESE
-
-THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
-WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
-MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+In addition to these special methods, this class exports the entire
+L<WWW::Search> interface.
 
 =cut
 
@@ -51,9 +30,6 @@ package WWW::Search::Yahoo::TV::Echostar;
 use Carp ();
 use Data::Dumper;  # for debugging only
 use Date::Manip;
-# We don't care what timezone we're in, we only use Date::Manip to
-# convert date formats:
-$ENV{'TZ'} ||= 'US/Eastern';
 use HTML::TreeBuilder;
 use WWW::Search qw( generic_option strip_tags );
 use WWW::Search::Result;
@@ -63,7 +39,7 @@ use strict;
 use vars qw( @ISA $VERSION $MAINTAINER );
 
 @ISA = qw( WWW::Search );
-$VERSION = sprintf("%d.%02d", q$Revision: 1.3 $ =~ /(\d+)\.(\d+)/o);
+$VERSION = sprintf("%d.%02d", q$Revision: 1.6 $ =~ /(\d+)\.(\d+)/o);
 $MAINTAINER = 'Martin Thurn <mthurn@cpan.org>';
 
 use constant DEBUG_SETUP => 0;
@@ -77,6 +53,8 @@ sub native_setup_search
 
   # www.yahoo.com refuses robots.
   $self->user_agent('non-robot');
+  # We don't care what the time zone really is:
+  &Date_Init(q{TZ=-0500});
 
   $self->{_next_to_retrieve} = 1;
 
@@ -125,7 +103,32 @@ sub native_setup_search
   } # native_setup_search
 
 
-sub preprocess_results_page
+=head2 ignore_channels(@)
+
+The arguments are a list of TV channels
+(by the 3- to 6-letter abbreviation used on Yahoo.com).
+URLs for TV programs on any of these channels will not be returned.
+(But note that approximate_result_count() will still count them!)
+
+For example, if you do not subscribe to HBO, and you don't care about
+network shows on the West Coast, do something like the following
+anytime before calling results() or next_result() or the like:
+
+  $oSearch->ignore_channels(qw( HBO HBOW HBO2E HBO2W KABC KCBS KNBC ));
+
+=cut
+
+sub ignore_channels
+  {
+  my $self = shift;
+  foreach my $sChannel (@_)
+    {
+    $self->{_ignore_channel}->{$sChannel} = 1;
+    } # foreach
+  } # ignore_channels
+
+
+sub preprocess_results_page_OFF
   {
   my $self = shift;
   my $sPage = shift;
@@ -185,6 +188,7 @@ sub parse_tree
           $sEpisode ||= '';
           print STDERR " +   episode==$sEpisode==\n" if (2 <= $self->{_debug});
           print STDERR " +   channel==$sChannel==\n" if (2 <= $self->{_debug});
+          next SMALL_TAG if exists($self->{_ignore_channel}->{$sChannel});
           print STDERR " +   datetime=$sDTG==\n" if (2 <= $self->{_debug});
           my $sDate = &UnixDate($sDTG, '%A, %b %E at %H:%M');
           my $sDesc = "$sDate on $sChannel";
@@ -206,3 +210,28 @@ sub parse_tree
 1;
 
 __END__
+
+=head1 NOTES
+
+This backend does a basic keyword search against the Echostar (Dish
+Network) East Coast channel lineup.
+
+=head1 SEE ALSO
+
+To make new back-ends, see L<WWW::Search>.
+
+=head1 BUGS
+
+Please tell the author if you find any!
+
+=head1 AUTHOR
+
+Martin Thurn C<mthurn@cpan.org>
+
+=head1 LEGALESE
+
+THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
+WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
+MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+
+=cut
